searchData={"items":[{"type":"module","title":"AshUUIDv7","doc":"Represents a UUID version 7.","ref":"AshUUIDv7.html"},{"type":"function","title":"AshUUIDv7.generate/0","doc":"","ref":"AshUUIDv7.html#generate/0"},{"type":"module","title":"AshUUIDv7.Extension","doc":"The `AshUUIDv7` extension.","ref":"AshUUIDv7.Extension.html"},{"type":"module","title":"AshUUIDv7.Helpers","doc":"Helpers for working with UUIDs version 7.\n\n[RFC 9562](https://www.rfc-editor.org/rfc/rfc9562#name-uuid-version-7)\n\nUsed for generating UUIDs version 7 with increased clock precision for better monotonicity,\nas described by method 3 of the [Section 6.2](https://www.rfc-editor.org/rfc/rfc9562#name-monotonicity-and-counters\n\nInspired by the work of [Ryan Winchester](https://github.com/ryanwinchester/) on [uuidv7](https://github.com/ryanwinchester/uuidv7)","ref":"AshUUIDv7.Helpers.html"},{"type":"module","title":"Examples - AshUUIDv7.Helpers","doc":"iex> UUIDv7.generate()\n    \"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\"\n\n    iex> UUIDv7.bingenerate()\n    <<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>","ref":"AshUUIDv7.Helpers.html#module-examples"},{"type":"function","title":"AshUUIDv7.Helpers.bingenerate/0","doc":"Generates a version 7 UUID in the binary format.","ref":"AshUUIDv7.Helpers.html#bingenerate/0"},{"type":"function","title":"Example - AshUUIDv7.Helpers.bingenerate/0","doc":"iex> UUIDv7.bingenerate()\n    <<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>","ref":"AshUUIDv7.Helpers.html#bingenerate/0-example"},{"type":"function","title":"AshUUIDv7.Helpers.decode/1","doc":"Decode a string representation of a UUID to the raw binary version.","ref":"AshUUIDv7.Helpers.html#decode/1"},{"type":"function","title":"Example - AshUUIDv7.Helpers.decode/1","doc":"iex> UUIDv7.decode(\"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\")\n    <<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>","ref":"AshUUIDv7.Helpers.html#decode/1-example"},{"type":"function","title":"AshUUIDv7.Helpers.encode/1","doc":"Encode a raw UUID to the string representation.","ref":"AshUUIDv7.Helpers.html#encode/1"},{"type":"function","title":"Example - AshUUIDv7.Helpers.encode/1","doc":"iex> UUIDv7.encode(<<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>)\n    \"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\"","ref":"AshUUIDv7.Helpers.html#encode/1-example"},{"type":"function","title":"AshUUIDv7.Helpers.extract_timestamp/1","doc":"Extract the millisecond timestamp from the UUID.","ref":"AshUUIDv7.Helpers.html#extract_timestamp/1"},{"type":"function","title":"Example - AshUUIDv7.Helpers.extract_timestamp/1","doc":"iex> UUIDv7.extract_timestamp(\"018ecb40-c457-73e6-a400-000398daddd9\")\n    1712807003223","ref":"AshUUIDv7.Helpers.html#extract_timestamp/1-example"},{"type":"function","title":"AshUUIDv7.Helpers.generate/0","doc":"Generates a version 7 UUID using submilliseconds for increased clock precision.","ref":"AshUUIDv7.Helpers.html#generate/0"},{"type":"function","title":"Example - AshUUIDv7.Helpers.generate/0","doc":"iex> UUIDv7.generate()\n    \"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\"","ref":"AshUUIDv7.Helpers.html#generate/0-example"},{"type":"type","title":"AshUUIDv7.Helpers.raw/0","doc":"A raw binary representation of a UUID.","ref":"AshUUIDv7.Helpers.html#t:raw/0"},{"type":"type","title":"AshUUIDv7.Helpers.t/0","doc":"A hex-encoded UUID string.","ref":"AshUUIDv7.Helpers.html#t:t/0"},{"type":"module","title":"AshUUIDv7.Info","doc":"Introspection functions for the `AshUUIDv7.Extension` extension.","ref":"AshUUIDv7.Info.html"},{"type":"module","title":"AshUUIDv7.PostgresExtension","doc":"The `AshUUIDv7` postgres extension.","ref":"AshUUIDv7.PostgresExtension.html"},{"type":"function","title":"AshUUIDv7.PostgresExtension.extension/0","doc":"","ref":"AshUUIDv7.PostgresExtension.html#extension/0"},{"type":"module","title":"AshUUIDv7.Transformers.PostgresMigrationDefaults","doc":"Set default values","ref":"AshUUIDv7.Transformers.PostgresMigrationDefaults.html"},{"type":"function","title":"AshUUIDv7.Transformers.PostgresMigrationDefaults.after?/1","doc":"","ref":"AshUUIDv7.Transformers.PostgresMigrationDefaults.html#after?/1"},{"type":"function","title":"AshUUIDv7.Transformers.PostgresMigrationDefaults.after_compile?/0","doc":"","ref":"AshUUIDv7.Transformers.PostgresMigrationDefaults.html#after_compile?/0"},{"type":"function","title":"AshUUIDv7.Transformers.PostgresMigrationDefaults.before?/1","doc":"","ref":"AshUUIDv7.Transformers.PostgresMigrationDefaults.html#before?/1"},{"type":"function","title":"AshUUIDv7.Transformers.PostgresMigrationDefaults.transform/1","doc":"","ref":"AshUUIDv7.Transformers.PostgresMigrationDefaults.html#transform/1"},{"type":"extras","title":"AshUUIDv7","doc":"# AshUUIDv7\n\n[![Hex](http://img.shields.io/hexpm/v/ash_uuid_v7.svg?style=flat)](https://hex.pm/packages/ash_uuid_v7)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-purple.svg)](https://hexdocs.pm/ash_uuid_v7)\n[![Build Status](https://img.shields.io/github/actions/workflow/status/zoonect-oss/ash_uuid_v7/ci.yml)](https://github.com/zoonect-oss/ash_uuid_v7)\n[![License](https://img.shields.io/github/license/zoonect-oss/ash_uuid_v7?color=blue)](https://github.com/zoonect-oss/ash_uuid_v7/blob/main/LICENSE.md)\n[![GitHub Stars](https://img.shields.io/github/stars/zoonect-oss/ash_uuid_v7?color=ffd700&label=github&logo=github)](https://github.com/zoonect-oss/ash_uuid_v7/stargazers)","ref":"readme.html"},{"type":"extras","title":"Installation - AshUUIDv7","doc":"```elixir\ndef deps do\n  [\n    {:ash_uuid_v7, \"~> 0.1.1\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Adoption - AshUUIDv7","doc":"Adoption:\n\n- add `{:ash_uuid_v7, \"~> 0.1.1\"}` to your `mix.exs` project deps;\n\n- add `AshUUIDv7.PostgresExtension` to your app Repo's installed_extensions if Postgres-side UUIDs generation is needed;\n\n- use the extension in your resources `use Ash.Resource, data_layer: AshPostgres.DataLayer, extensions: [AshUUIDv7.Extension]`;\n\n- simply use that for your fields `uuid_v7_primary_key :id`.","ref":"readme.html#adoption"},{"type":"extras","title":"Configuration - AshUUIDv7","doc":"### `lib/myapp/repo.ex`:\n\nUsing the PostgresExtension allows postgres-side uuid-v7 generation.\n\n```elixir\n# App: Postgres migration defaults, not required\n`\ndefmodule Myapp.Repo do\n  use AshPostgres.Repo, otp_app: :myapp\n\n  @impl AshPostgres.Repo\n  def installed_extensions do\n    [\"ash-functions\", \"uuid-ossp\", \"citext\", AshUUIDv7.PostgresExtension]\n  end\nend\n```\n\n### `config/config.exs`:\n\n```elixir\n# Ash: Type shorthands, not required\nconfig :ash, :custom_types, uuid_v7: AshUUIDv7\n\n# Ash: Default belongs_to type, not required\nconfig :ash, :default_belongs_to_type, AshUUIDv7\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - AshUUIDv7","doc":"```elixir\ndefmodule Pineapple do\n  use Ash.Resource, data_layer: AshPostgres.DataLayer, extensions: [AshUUIDv7.Extension]\n\n  code_interface do\n    define_for Area\n  end\n\n  postgres do\n    table \"pineapples\"\n    repo MyApp.Repo\n  end\n\n  attributes do\n    uuid_v7_primary_key :id\n    attribute :uuid_field, :uuid_v7\n\n    create_timestamp :inserted_at\n  end\n\n  actions do\n    defaults [:create, :read, :update]\n  end\nend\n```\n\nThe full documentation can be found [on HexDocs].","ref":"readme.html#usage"},{"type":"extras","title":"Roadmap - AshUUIDv7","doc":"-","ref":"readme.html#roadmap"},{"type":"extras","title":"Developing - AshUUIDv7","doc":"To get set up with the development environment, you will need a Postgres\ninstance and an environment variable DATABASE_URL according to `config/config.exs`.\n\nYou may now generate and apply the test migrations:\n\n```sh\nmix ash_postgres.generate_migrations\nmix ash_postgres.create\nmix ash_postgres.migrate\nmix test\n```\n\n**AshUUIDv7** uses `ex_check` to bundle the test configuration, and simply running\n`mix check` should closely follow the configuration used in CI.","ref":"readme.html#developing"},{"type":"extras","title":"Contributing - AshUUIDv7","doc":"If you have ideas or come across any bugs, feel free to open a [pull request] or\nan [issue]. You can also find me on the [Ash Discord](https://discord.gg/D7FNG2q) as `@moissela`.","ref":"readme.html#contributing"},{"type":"extras","title":"License - AshUUIDv7","doc":"MIT License\n\nCopyright (c) 2024 [Alessio Montagnani]\n\nSee [LICENSE.md] for details.\n\n[Alessio Montagnani]: https://github.com/moissela\n[LICENSE.md]: https://github.com/zoonect-oss/ash_uuid_v7/blob/main/LICENSE.md\n[pull request]: https://github.com/zoonect-oss/ash_uuid_v7/pulls\n[issue]: https://github.com/zoonect-oss/ash_uuid_v7/issues\n[on HexDocs]: https://hexdocs.pm/ash_uuid_v7","ref":"readme.html#license"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [v0.1.1](https://github.com/zoonect-oss/ash_uuid_v7/compare/v0.1.0...v0.1.1) (2024-07-01)","ref":"changelog.html"},{"type":"extras","title":"Improvements: - Change Log","doc":"* remove non-simple equality check\n\n## [v0.1.0](https://github.com/zoonect-oss/ash_uuid_v7/compare/v0.1.0...v0.1.0) (2024-06-25)","ref":"changelog.html#improvements"},{"type":"extras","title":"Features: - Change Log","doc":"* first implementation","ref":"changelog.html#features"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}